# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`keycloak`](#keycloak): Manage Keycloak
* [`keycloak::config`](#keycloakconfig): Private class.
* [`keycloak::datasource::h2`](#keycloakdatasourceh2): Private class.
* [`keycloak::install`](#keycloakinstall): Private class.
* [`keycloak::service`](#keycloakservice): Private class.
* [`keycloak::sssd`](#keycloaksssd): Private class.

#### Private Classes

* `keycloak::datasource::mysql`: Manage MySQL datasource
* `keycloak::datasource::oracle`: Manage Oracle datasource
* `keycloak::datasource::postgresql`: Manage postgresql datasource
* `keycloak::resources`: Define Keycloak resources

### Defined types

* [`keycloak::client_scope::oidc`](#keycloakclient_scopeoidc): Manage Keycloak OpenID Connect client scope using built-in mappers
* [`keycloak::client_scope::saml`](#keycloakclient_scopesaml): Manage Keycloak SAML client scope using built-in mappers
* [`keycloak::freeipa_ldap_mappers`](#keycloakfreeipa_ldap_mappers): setup FreeIPA LDAP mappers for Keycloak
* [`keycloak::freeipa_user_provider`](#keycloakfreeipa_user_provider): setup IPA as an LDAP user provider for Keycloak
* [`keycloak::spi_deployment`](#keycloakspi_deployment): Manage Keycloak SPI deployment
* [`keycloak::truststore::host`](#keycloaktruststorehost): Add host to Keycloak truststore

### Resource types

* [`keycloak_api`](#keycloak_api): Type that configures API connection parameters for other keycloak types that use the Keycloak API.
* [`keycloak_client`](#keycloak_client): Manage Keycloak clients
* [`keycloak_client_protocol_mapper`](#keycloak_client_protocol_mapper): Manage Keycloak protocol mappers
* [`keycloak_client_scope`](#keycloak_client_scope): Manage Keycloak client scopes
* [`keycloak_conn_validator`](#keycloak_conn_validator): Verify that a connection can be successfully established between a node and the keycloak server.  Its primary use is as a precondition to pre
* [`keycloak_flow`](#keycloak_flow): Manage a Keycloak flow **Autorequires** * `keycloak_realm` defined for `realm` parameter * `keycloak_flow` of `flow_alias` if `top_level=fals
* [`keycloak_flow_execution`](#keycloak_flow_execution): Manage a Keycloak flow **Autorequires** * `keycloak_realm` defined for `realm` parameter * `keycloak_flow` of value defined for `flow_alias` 
* [`keycloak_identity_provider`](#keycloak_identity_provider): Manage Keycloak identity providers
* [`keycloak_ldap_mapper`](#keycloak_ldap_mapper): Manage Keycloak LDAP attribute mappers
* [`keycloak_ldap_user_provider`](#keycloak_ldap_user_provider): Manage Keycloak LDAP user providers
* [`keycloak_protocol_mapper`](#keycloak_protocol_mapper): Manage Keycloak client scope protocol mappers
* [`keycloak_realm`](#keycloak_realm): Manage Keycloak realms
* [`keycloak_required_action`](#keycloak_required_action): Manage Keycloak required actions
* [`keycloak_resource_validator`](#keycloak_resource_validator): Verify that a specific Keycloak resource is available
* [`keycloak_sssd_user_provider`](#keycloak_sssd_user_provider): Manage Keycloak SSSD user providers

## Classes

### <a name="keycloak"></a>`keycloak`

Manage Keycloak

#### Examples

##### 

```puppet
include ::keycloak
```

#### Parameters

The following parameters are available in the `keycloak` class:

* [`manage_install`](#manage_install)
* [`version`](#version)
* [`package_url`](#package_url)
* [`install_dir`](#install_dir)
* [`service_name`](#service_name)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`service_hasstatus`](#service_hasstatus)
* [`service_hasrestart`](#service_hasrestart)
* [`service_bind_address`](#service_bind_address)
* [`management_bind_address`](#management_bind_address)
* [`java_opts`](#java_opts)
* [`java_opts_append`](#java_opts_append)
* [`service_extra_opts`](#service_extra_opts)
* [`manage_user`](#manage_user)
* [`user`](#user)
* [`user_shell`](#user_shell)
* [`group`](#group)
* [`user_uid`](#user_uid)
* [`group_gid`](#group_gid)
* [`system_user`](#system_user)
* [`admin_user`](#admin_user)
* [`admin_user_password`](#admin_user_password)
* [`wildfly_user`](#wildfly_user)
* [`wildfly_user_password`](#wildfly_user_password)
* [`manage_datasource`](#manage_datasource)
* [`datasource_driver`](#datasource_driver)
* [`datasource_host`](#datasource_host)
* [`datasource_port`](#datasource_port)
* [`datasource_url`](#datasource_url)
* [`datasource_dbname`](#datasource_dbname)
* [`datasource_username`](#datasource_username)
* [`datasource_password`](#datasource_password)
* [`datasource_package`](#datasource_package)
* [`datasource_jar_source`](#datasource_jar_source)
* [`datasource_jar_filename`](#datasource_jar_filename)
* [`datasource_module_source`](#datasource_module_source)
* [`datasource_xa_class`](#datasource_xa_class)
* [`mysql_database_charset`](#mysql_database_charset)
* [`proxy_https`](#proxy_https)
* [`truststore`](#truststore)
* [`truststore_hosts`](#truststore_hosts)
* [`truststore_password`](#truststore_password)
* [`truststore_hostname_verification_policy`](#truststore_hostname_verification_policy)
* [`http_port`](#http_port)
* [`theme_static_max_age`](#theme_static_max_age)
* [`theme_cache_themes`](#theme_cache_themes)
* [`theme_cache_templates`](#theme_cache_templates)
* [`realms`](#realms)
* [`realms_merge`](#realms_merge)
* [`oidc_client_scopes`](#oidc_client_scopes)
* [`oidc_client_scopes_merge`](#oidc_client_scopes_merge)
* [`saml_client_scopes`](#saml_client_scopes)
* [`saml_client_scopes_merge`](#saml_client_scopes_merge)
* [`identity_providers`](#identity_providers)
* [`identity_providers_merge`](#identity_providers_merge)
* [`client_protocol_mappers`](#client_protocol_mappers)
* [`client_scopes`](#client_scopes)
* [`client_scopes_merge`](#client_scopes_merge)
* [`protocol_mappers`](#protocol_mappers)
* [`protocol_mappers_merge`](#protocol_mappers_merge)
* [`clients`](#clients)
* [`clients_merge`](#clients_merge)
* [`flows`](#flows)
* [`flows_merge`](#flows_merge)
* [`flow_executions`](#flow_executions)
* [`flow_executions_merge`](#flow_executions_merge)
* [`required_actions`](#required_actions)
* [`required_actions_merge`](#required_actions_merge)
* [`ldap_mappers`](#ldap_mappers)
* [`ldap_mappers_merge`](#ldap_mappers_merge)
* [`ldap_user_providers`](#ldap_user_providers)
* [`ldap_user_providers_merge`](#ldap_user_providers_merge)
* [`with_sssd_support`](#with_sssd_support)
* [`libunix_dbus_java_source`](#libunix_dbus_java_source)
* [`install_libunix_dbus_java_build_dependencies`](#install_libunix_dbus_java_build_dependencies)
* [`libunix_dbus_java_build_dependencies`](#libunix_dbus_java_build_dependencies)
* [`libunix_dbus_java_libdir`](#libunix_dbus_java_libdir)
* [`jna_package_name`](#jna_package_name)
* [`manage_sssd_config`](#manage_sssd_config)
* [`sssd_ifp_user_attributes`](#sssd_ifp_user_attributes)
* [`restart_sssd`](#restart_sssd)
* [`service_environment_file`](#service_environment_file)
* [`operating_mode`](#operating_mode)
* [`enable_jdbc_ping`](#enable_jdbc_ping)
* [`jboss_bind_public_address`](#jboss_bind_public_address)
* [`jboss_bind_private_address`](#jboss_bind_private_address)
* [`role`](#role)
* [`user_cache`](#user_cache)
* [`tech_preview_features`](#tech_preview_features)
* [`auto_deploy_exploded`](#auto_deploy_exploded)
* [`auto_deploy_zipped`](#auto_deploy_zipped)
* [`spi_deployments`](#spi_deployments)
* [`custom_config_content`](#custom_config_content)
* [`custom_config_source`](#custom_config_source)
* [`master_address`](#master_address)
* [`server_name`](#server_name)
* [`syslog`](#syslog)
* [`syslog_app_name`](#syslog_app_name)
* [`syslog_facility`](#syslog_facility)
* [`syslog_hostname`](#syslog_hostname)
* [`syslog_level`](#syslog_level)
* [`syslog_port`](#syslog_port)
* [`syslog_server_address`](#syslog_server_address)
* [`syslog_format`](#syslog_format)

##### <a name="manage_install"></a>`manage_install`

Data type: `Boolean`

Install Keycloak from upstream Keycloak tarball.
Set to false to manage installation of Keycloak outside
this module and set $install_dir to match.
Defaults to true.

Default value: ``true``

##### <a name="version"></a>`version`

Data type: `String`

Version of Keycloak to install and manage.

Default value: `'12.0.4'`

##### <a name="package_url"></a>`package_url`

Data type: `Optional[Variant[Stdlib::HTTPUrl, Stdlib::HTTPSUrl]]`

URL of the Keycloak download.
Default is based on version.

Default value: ``undef``

##### <a name="install_dir"></a>`install_dir`

Data type: `Optional[Stdlib::Absolutepath]`

The directory of where to install Keycloak.
Default is `/opt/keycloak-${version}`.

Default value: ``undef``

##### <a name="service_name"></a>`service_name`

Data type: `String`

Keycloak service name.
Default is `keycloak`.

Default value: `'keycloak'`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `String`

Keycloak service ensure property.
Default is `running`.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

Keycloak service enable property.
Default is `true`.

Default value: ``true``

##### <a name="service_hasstatus"></a>`service_hasstatus`

Data type: `Boolean`

Keycloak service hasstatus parameter.
Default is `true`.

Default value: ``true``

##### <a name="service_hasrestart"></a>`service_hasrestart`

Data type: `Boolean`

Keycloak service hasrestart parameter.
Default is `true`.

Default value: ``true``

##### <a name="service_bind_address"></a>`service_bind_address`

Data type: `Stdlib::IP::Address`

Bind address for Keycloak service.
Default is '0.0.0.0'.

Default value: `'0.0.0.0'`

##### <a name="management_bind_address"></a>`management_bind_address`

Data type: `Stdlib::IP::Address`

Bind address for Keycloak management.
Default is '0.0.0.0'.

Default value: `'0.0.0.0'`

##### <a name="java_opts"></a>`java_opts`

Data type: `Optional[Variant[String, Array]]`

Sets additional options to Java virtual machine environment variable.

Default value: ``undef``

##### <a name="java_opts_append"></a>`java_opts_append`

Data type: `Boolean`

Determine if $JAVA_OPTS should be appended to when setting `java_opts` parameter

Default value: ``true``

##### <a name="service_extra_opts"></a>`service_extra_opts`

Data type: `Optional[String]`

Additional options added to the end of the service command-line.

Default value: ``undef``

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Defines if the module should manage the Linux user for Keycloak installation

Default value: ``true``

##### <a name="user"></a>`user`

Data type: `String`

Keycloak user name.
Default is `keycloak`.

Default value: `'keycloak'`

##### <a name="user_shell"></a>`user_shell`

Data type: `Stdlib::Absolutepath`

Keycloak user shell.

Default value: `'/sbin/nologin'`

##### <a name="group"></a>`group`

Data type: `String`

Keycloak user group name.
Default is `keycloak`.

Default value: `'keycloak'`

##### <a name="user_uid"></a>`user_uid`

Data type: `Optional[Integer]`

Keycloak user UID.
Default is `undef`.

Default value: ``undef``

##### <a name="group_gid"></a>`group_gid`

Data type: `Optional[Integer]`

Keycloak user group GID.
Default is `undef`.

Default value: ``undef``

##### <a name="system_user"></a>`system_user`

Data type: `Boolean`

If keycloak user should be a system user with lower uid and gid.
Default is `true`

Default value: ``true``

##### <a name="admin_user"></a>`admin_user`

Data type: `String`

Keycloak administrative username.
Default is `admin`.

Default value: `'admin'`

##### <a name="admin_user_password"></a>`admin_user_password`

Data type: `String`

Keycloak administrative user password.
Default is `changeme`.

Default value: `'changeme'`

##### <a name="wildfly_user"></a>`wildfly_user`

Data type: `Optional[String]`

Wildfly user. Required for domain mode.

Default value: ``undef``

##### <a name="wildfly_user_password"></a>`wildfly_user_password`

Data type: `Optional[String]`

Wildfly user password. Required for domain mode.

Default value: ``undef``

##### <a name="manage_datasource"></a>`manage_datasource`

Data type: `Boolean`

Boolean that determines if configured datasource will be managed.
Default is `true`.

Default value: ``true``

##### <a name="datasource_driver"></a>`datasource_driver`

Data type: `Enum['h2', 'mysql', 'oracle', 'postgresql']`

Datasource driver to use for Keycloak.
Valid values are `h2`, `mysql`, 'oracle' and 'postgresql'
Default is `h2`.

Default value: `'h2'`

##### <a name="datasource_host"></a>`datasource_host`

Data type: `Optional[String]`

Datasource host.
Only used when datasource_driver is `mysql`, 'oracle' or 'postgresql'
Default is `localhost` for MySQL.

Default value: ``undef``

##### <a name="datasource_port"></a>`datasource_port`

Data type: `Optional[Integer]`

Datasource port.
Only used when datasource_driver is `mysql`, 'oracle' or 'postgresql'
Default is `3306` for MySQL.

Default value: ``undef``

##### <a name="datasource_url"></a>`datasource_url`

Data type: `Optional[String]`

Datasource url.
Default datasource URLs are defined in init class.

Default value: ``undef``

##### <a name="datasource_dbname"></a>`datasource_dbname`

Data type: `String`

Datasource database name.
Default is `keycloak`.

Default value: `'keycloak'`

##### <a name="datasource_username"></a>`datasource_username`

Data type: `String`

Datasource user name.
Default is `sa`.

Default value: `'sa'`

##### <a name="datasource_password"></a>`datasource_password`

Data type: `String`

Datasource user password.
Default is `sa`.

Default value: `'sa'`

##### <a name="datasource_package"></a>`datasource_package`

Data type: `Optional[String]`

Package to add specified datasource support

Default value: ``undef``

##### <a name="datasource_jar_source"></a>`datasource_jar_source`

Data type: `Optional[String]`

Source for datasource JDBC driver - could be puppet link or local file on the node.
Default is dependent on value for `datasource_driver`.
This parameter is required if `datasource_driver` is `oracle`.

Default value: ``undef``

##### <a name="datasource_jar_filename"></a>`datasource_jar_filename`

Data type: `Optional[String]`

Specify the filename of the destination datasource jar in the module dir of keycloak.
This parameter is only working at the moment if `datasource_driver` is `oracle`.

Default value: ``undef``

##### <a name="datasource_module_source"></a>`datasource_module_source`

Data type: `Optional[String]`

Source for datasource module.xml. Default depends on `datasource_driver`.

Default value: ``undef``

##### <a name="datasource_xa_class"></a>`datasource_xa_class`

Data type: `Optional[String]`

MySQL Connector/J JDBC driver xa-datasource class name

Default value: ``undef``

##### <a name="mysql_database_charset"></a>`mysql_database_charset`

Data type: `String`

MySQL database charset

Default value: `'utf8'`

##### <a name="proxy_https"></a>`proxy_https`

Data type: `Boolean`

Boolean that sets if HTTPS proxy should be enabled.
Set to `true` if proxying traffic through Apache.
Default is `false`.

Default value: ``false``

##### <a name="truststore"></a>`truststore`

Data type: `Boolean`

Boolean that sets if truststore should be used.
Default is `false`.

Default value: ``false``

##### <a name="truststore_hosts"></a>`truststore_hosts`

Data type: `Hash`

Hash that is used to define `keycloak::turststore::host` resources.
Default is `{}`.

Default value: `{}`

##### <a name="truststore_password"></a>`truststore_password`

Data type: `String`

Truststore password.
Default is `keycloak`.

Default value: `'keycloak'`

##### <a name="truststore_hostname_verification_policy"></a>`truststore_hostname_verification_policy`

Data type: `Enum['WILDCARD', 'STRICT', 'ANY']`

Valid values are `WILDCARD`, `STRICT`, and `ANY`.
Default is `WILDCARD`.

Default value: `'WILDCARD'`

##### <a name="http_port"></a>`http_port`

Data type: `Integer`

HTTP port used by Keycloak.
Default is `8080`.

Default value: `8080`

##### <a name="theme_static_max_age"></a>`theme_static_max_age`

Data type: `Integer`

Max cache age in seconds of static content.
Default is `2592000`.

Default value: `2592000`

##### <a name="theme_cache_themes"></a>`theme_cache_themes`

Data type: `Boolean`

Boolean that sets if themes should be cached.
Default is `true`.

Default value: ``true``

##### <a name="theme_cache_templates"></a>`theme_cache_templates`

Data type: `Boolean`

Boolean that sets if templates should be cached.
Default is `true`.

Default value: ``true``

##### <a name="realms"></a>`realms`

Data type: `Hash`

Hash that is used to define keycloak_realm resources.
Default is `{}`.

Default value: `{}`

##### <a name="realms_merge"></a>`realms_merge`

Data type: `Boolean`

Boolean that sets if `realms` should be merged from Hiera.

Default value: ``false``

##### <a name="oidc_client_scopes"></a>`oidc_client_scopes`

Data type: `Hash`

Hash that is used to define keycloak::client_scope::oidc resources.
Default is `{}`.

Default value: `{}`

##### <a name="oidc_client_scopes_merge"></a>`oidc_client_scopes_merge`

Data type: `Boolean`

Boolean that sets if `oidc_client_scopes` should be merged from Hiera.

Default value: ``false``

##### <a name="saml_client_scopes"></a>`saml_client_scopes`

Data type: `Hash`

Hash that is used to define keycloak::client_scope::saml resources.
Default is `{}`.

Default value: `{}`

##### <a name="saml_client_scopes_merge"></a>`saml_client_scopes_merge`

Data type: `Boolean`

Boolean that sets if `saml_client_scopes` should be merged from Hiera.

Default value: ``false``

##### <a name="identity_providers"></a>`identity_providers`

Data type: `Hash`

Hash that is used to define keycloak_identity_provider resources.

Default value: `{}`

##### <a name="identity_providers_merge"></a>`identity_providers_merge`

Data type: `Boolean`

Boolean that sets if `identity_providers` should be merged from Hiera.

Default value: ``false``

##### <a name="client_protocol_mappers"></a>`client_protocol_mappers`

Data type: `Hash`

Hash that is used to define keycloak_client_protocol_mapper resources.

Default value: `{}`

##### <a name="client_scopes"></a>`client_scopes`

Data type: `Hash`

Hash that is used to define keycloak_client_scope resources.

Default value: `{}`

##### <a name="client_scopes_merge"></a>`client_scopes_merge`

Data type: `Boolean`

Boolean that sets if `client_scopes` should be merged from Hiera.

Default value: ``false``

##### <a name="protocol_mappers"></a>`protocol_mappers`

Data type: `Hash`

Hash that is used to define keycloak_protocol_mapper resources.

Default value: `{}`

##### <a name="protocol_mappers_merge"></a>`protocol_mappers_merge`

Data type: `Boolean`

Boolean that sets if `protocol_mappers` should be merged from Hiera.

Default value: ``false``

##### <a name="clients"></a>`clients`

Data type: `Hash`

Hash that is used to define keycloak_client resources.

Default value: `{}`

##### <a name="clients_merge"></a>`clients_merge`

Data type: `Boolean`

Boolean that sets if `clients` should be merged from Hiera.

Default value: ``false``

##### <a name="flows"></a>`flows`

Data type: `Hash`

Hash taht is used to define keycloak_flow resources.

Default value: `{}`

##### <a name="flows_merge"></a>`flows_merge`

Data type: `Boolean`

Boolean that sets if `flows` should be merged from Hiera.

Default value: ``false``

##### <a name="flow_executions"></a>`flow_executions`

Data type: `Hash`

Hash taht is used to define keycloak_flow resources.

Default value: `{}`

##### <a name="flow_executions_merge"></a>`flow_executions_merge`

Data type: `Boolean`

Boolean that sets if `flows` should be merged from Hiera.

Default value: ``false``

##### <a name="required_actions"></a>`required_actions`

Data type: `Hash`

Hash that is used to define keycloak_required_action resources.

Default value: `{}`

##### <a name="required_actions_merge"></a>`required_actions_merge`

Data type: `Boolean`

Boolean that sets if `required_actions` should be merged from Hiera.

Default value: ``false``

##### <a name="ldap_mappers"></a>`ldap_mappers`

Data type: `Hash`

Hash that is used to define keycloak_ldap_mapper resources.

Default value: `{}`

##### <a name="ldap_mappers_merge"></a>`ldap_mappers_merge`

Data type: `Boolean`

Boolean that sets if `ldap_mappers` should be merged from Hiera.

Default value: ``false``

##### <a name="ldap_user_providers"></a>`ldap_user_providers`

Data type: `Hash`

Hash that is used to define keycloak_ldap_user_provider resources.

Default value: `{}`

##### <a name="ldap_user_providers_merge"></a>`ldap_user_providers_merge`

Data type: `Boolean`

Boolean that sets if `ldap_user_providers` should be merged from Hiera.

Default value: ``false``

##### <a name="with_sssd_support"></a>`with_sssd_support`

Data type: `Boolean`

Boolean that determines if SSSD user provider support should be available

Default value: ``false``

##### <a name="libunix_dbus_java_source"></a>`libunix_dbus_java_source`

Data type: `Variant[Stdlib::HTTPUrl, Stdlib::HTTPSUrl]`

Source URL of libunix-dbus-java

Default value: `'https://github.com/keycloak/libunix-dbus-java/archive/libunix-dbus-java-0.8.0.tar.gz'`

##### <a name="install_libunix_dbus_java_build_dependencies"></a>`install_libunix_dbus_java_build_dependencies`

Data type: `Boolean`

Boolean that determines of libunix-dbus-java build dependencies are managed by this module

Default value: ``true``

##### <a name="libunix_dbus_java_build_dependencies"></a>`libunix_dbus_java_build_dependencies`

Data type: `Array`

Packages needed to build libunix-dbus-java

Default value: `[]`

##### <a name="libunix_dbus_java_libdir"></a>`libunix_dbus_java_libdir`

Data type: `Stdlib::Absolutepath`

Path to directory to install libunix-dbus-java libraries

Default value: `'/usr/lib64'`

##### <a name="jna_package_name"></a>`jna_package_name`

Data type: `String`

Package name for jna

Default value: `'jna'`

##### <a name="manage_sssd_config"></a>`manage_sssd_config`

Data type: `Boolean`

Boolean that determines if SSSD ifp config for Keycloak is managed

Default value: ``true``

##### <a name="sssd_ifp_user_attributes"></a>`sssd_ifp_user_attributes`

Data type: `Array`

user_attributes to define for SSSD ifp service

Default value: `[]`

##### <a name="restart_sssd"></a>`restart_sssd`

Data type: `Boolean`

Boolean that determines if SSSD should be restarted

Default value: ``true``

##### <a name="service_environment_file"></a>`service_environment_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the file with environment variables for the systemd service

Default value: ``undef``

##### <a name="operating_mode"></a>`operating_mode`

Data type: `Enum['standalone', 'clustered', 'domain']`

Keycloak operating mode deployment

Default value: `'standalone'`

##### <a name="enable_jdbc_ping"></a>`enable_jdbc_ping`

Data type: `Boolean`

Use JDBC_PING to discover the nodes and manage the replication of data
  More info: http://jgroups.org/manual/#_jdbc_ping
Only applies when `operating_mode` is either `clustered` or `domain`
JDBC_PING uses port 7600 to ensure cluster members are discoverable by each other
This module does not manage firewall changes

Default value: ``false``

##### <a name="jboss_bind_public_address"></a>`jboss_bind_public_address`

Data type: `Stdlib::IP::Address`

JBoss bind public IP address

Default value: `$facts['networking']['ip']`

##### <a name="jboss_bind_private_address"></a>`jboss_bind_private_address`

Data type: `Stdlib::IP::Address`

JBoss bind private IP address

Default value: `$facts['networking']['ip']`

##### <a name="role"></a>`role`

Data type: `Optional[Enum['master', 'slave']]`

Role when operating mode is domain.

Default value: ``undef``

##### <a name="user_cache"></a>`user_cache`

Data type: `Boolean`

Boolean that determines if userCache is enabled

Default value: ``true``

##### <a name="tech_preview_features"></a>`tech_preview_features`

Data type: `Array`

List of technology Preview features to enable

Default value: `[]`

##### <a name="auto_deploy_exploded"></a>`auto_deploy_exploded`

Data type: `Boolean`

Set if exploded deployements will be auto deployed

Default value: ``false``

##### <a name="auto_deploy_zipped"></a>`auto_deploy_zipped`

Data type: `Boolean`

Set if zipped deployments will be auto deployed

Default value: ``true``

##### <a name="spi_deployments"></a>`spi_deployments`

Data type: `Hash`

Hash used to define keycloak::spi_deployment resources

Default value: `{}`

##### <a name="custom_config_content"></a>`custom_config_content`

Data type: `Optional[String]`

Custom configuration content to be added to config.cli

Default value: ``undef``

##### <a name="custom_config_source"></a>`custom_config_source`

Data type: `Optional[Variant[String, Array]]`

Custom configuration source file to be added to config.cli

Default value: ``undef``

##### <a name="master_address"></a>`master_address`

Data type: `Optional[Stdlib::Host]`

IP address of the master in domain mode

Default value: ``undef``

##### <a name="server_name"></a>`server_name`

Data type: `String`

Server name in domain mode. Defaults to hostname.

Default value: `$facts['hostname']`

##### <a name="syslog"></a>`syslog`

Data type: `Boolean`

Enable syslog. Default false.

Default value: ``false``

##### <a name="syslog_app_name"></a>`syslog_app_name`

Data type: `String`

Syslog app name. Default 'keycloak'.

Default value: `'keycloak'`

##### <a name="syslog_facility"></a>`syslog_facility`

Data type: `String`

Syslog facility. Default 'user-level'. See https://docs.jboss.org/author/display/AS72/Logging%20Configuration.html

Default value: `'user-level'`

##### <a name="syslog_hostname"></a>`syslog_hostname`

Data type: `Stdlib::Host`

Syslog hostname of the server. Default $facts['fqdn'].

Default value: `$facts['fqdn']`

##### <a name="syslog_level"></a>`syslog_level`

Data type: `String`

Syslog level. Default 'INFO'. See https://docs.jboss.org/author/display/AS72/Logging%20Configuration.html

Default value: `'INFO'`

##### <a name="syslog_port"></a>`syslog_port`

Data type: `Stdlib::Port`

The port the syslog server is listening on. Default '514'.

Default value: `514`

##### <a name="syslog_server_address"></a>`syslog_server_address`

Data type: `Stdlib::Host`

The address of the syslog server. Default 'localhost'.

Default value: `'localhost'`

##### <a name="syslog_format"></a>`syslog_format`

Data type: `Enum['RFC3164', 'RFC5424']`

Syslog format. Either 'RFC3164' or 'RFC5424' Default 'RFC3164'.

Default value: `'RFC3164'`

### <a name="keycloakconfig"></a>`keycloak::config`

Private class.

### <a name="keycloakdatasourceh2"></a>`keycloak::datasource::h2`

Private class.

### <a name="keycloakinstall"></a>`keycloak::install`

Private class.

### <a name="keycloakservice"></a>`keycloak::service`

Private class.

### <a name="keycloaksssd"></a>`keycloak::sssd`

Private class.

## Defined types

### <a name="keycloakclient_scopeoidc"></a>`keycloak::client_scope::oidc`

Manage Keycloak OpenID Connect client scope using built-in mappers

#### Examples

##### 

```puppet
keycloak::client_scope::oidc { 'oidc-clients':
  realm => 'test',
}
```

#### Parameters

The following parameters are available in the `keycloak::client_scope::oidc` defined type:

* [`realm`](#realm)
* [`resource_name`](#resource_name)

##### <a name="realm"></a>`realm`

Data type: `String`

Realm of the client scope.

##### <a name="resource_name"></a>`resource_name`

Data type: `String`

Name of the client scope resource

Default value: `$name`

### <a name="keycloakclient_scopesaml"></a>`keycloak::client_scope::saml`

Manage Keycloak SAML client scope using built-in mappers

#### Examples

##### 

```puppet
keycloak::client_scope::saml { 'saml-clients':
  realm => 'test',
}
```

#### Parameters

The following parameters are available in the `keycloak::client_scope::saml` defined type:

* [`realm`](#realm)
* [`resource_name`](#resource_name)

##### <a name="realm"></a>`realm`

Data type: `String`

Realm of the client scope.

##### <a name="resource_name"></a>`resource_name`

Data type: `String`

Name of the client scope resource

Default value: `$name`

### <a name="keycloakfreeipa_ldap_mappers"></a>`keycloak::freeipa_ldap_mappers`

setup FreeIPA LDAP mappers for Keycloak

#### Examples

##### 

```puppet
keycloak::freeipa_ldap_mappers { 'ipa.example.org':
  realm            => 'EXAMPLE.ORG',
  groups_dn        => 'cn=groups,cn=accounts,dc=example,dc=org',
  roles_dn         => 'cn=groups,cn=accounts,dc=example,dc=org'
}
```

#### Parameters

The following parameters are available in the `keycloak::freeipa_ldap_mappers` defined type:

* [`realm`](#realm)
* [`groups_dn`](#groups_dn)
* [`roles_dn`](#roles_dn)
* [`parent_id`](#parent_id)

##### <a name="realm"></a>`realm`

Data type: `String`

Keycloak realm

##### <a name="groups_dn"></a>`groups_dn`

Data type: `String`

Groups DN

##### <a name="roles_dn"></a>`roles_dn`

Data type: `String`

Roles DN

##### <a name="parent_id"></a>`parent_id`

Data type: `Optional[String]`

Identifier (parentId) for the LDAP provider to add this mapper to.
Will be passed to the $ldap parameter in keycloak_ldap_mapper.

Default value: ``undef``

### <a name="keycloakfreeipa_user_provider"></a>`keycloak::freeipa_user_provider`

setup IPA as an LDAP user provider for Keycloak

#### Examples

##### Add FreeIPA as a user provider

```puppet
keycloak::freeipa_user_provider { 'ipa.example.org':
  ensure          => 'present',
  realm           => 'EXAMPLE.ORG',
  bind_dn         => 'uid=ldapproxy,cn=sysaccounts,cn=etc,dc=example,dc=org',
  bind_credential => 'secret',
  users_dn        => 'cn=users,cn=accounts,dc=example,dc=org',
  priority        => 10,
}
```

#### Parameters

The following parameters are available in the `keycloak::freeipa_user_provider` defined type:

* [`ensure`](#ensure)
* [`id`](#id)
* [`ipa_host`](#ipa_host)
* [`realm`](#realm)
* [`bind_dn`](#bind_dn)
* [`bind_credential`](#bind_credential)
* [`users_dn`](#users_dn)
* [`priority`](#priority)
* [`ldaps`](#ldaps)
* [`full_sync_period`](#full_sync_period)
* [`changed_sync_period`](#changed_sync_period)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

LDAP user provider status

Default value: `'present'`

##### <a name="id"></a>`id`

Data type: `Optional[String]`

ID to use for user provider

Default value: ``undef``

##### <a name="ipa_host"></a>`ipa_host`

Data type: `Stdlib::Host`

Hostname of the FreeIPA server (e.g. ipa.example.org)

Default value: `$title`

##### <a name="realm"></a>`realm`

Data type: `String`

Keycloak realm

##### <a name="bind_dn"></a>`bind_dn`

Data type: `String`

LDAP bind dn

##### <a name="bind_credential"></a>`bind_credential`

Data type: `String`

LDAP bind password

##### <a name="users_dn"></a>`users_dn`

Data type: `String`

The DN for user search

##### <a name="priority"></a>`priority`

Data type: `Integer`

Priority for this user provider

Default value: `10`

##### <a name="ldaps"></a>`ldaps`

Data type: `Boolean`

Use LDAPS protocol instead of LDAP

Default value: ``false``

##### <a name="full_sync_period"></a>`full_sync_period`

Data type: `Optional[Integer]`

Synchronize all users this often (fullSyncPeriod)

Default value: ``undef``

##### <a name="changed_sync_period"></a>`changed_sync_period`

Data type: `Optional[Integer]`

Synchronize changed users this often (changedSyncPeriod)

Default value: ``undef``

### <a name="keycloakspi_deployment"></a>`keycloak::spi_deployment`

}

#### Examples

##### Add Duo SPI

```puppet
keycloak::spi_deployment { 'duo-spi':
  ensure        => 'present',
  deployed_name => 'keycloak-duo-spi-jar-with-dependencies.jar',
  source        => 'file:///path/to/source/keycloak-duo-spi-jar-with-dependencies.jar',
}
```

##### Add Duo SPI and check API for existance of resources before going onto dependenct resources

```puppet
keycloak::spi_deployment { 'duo-spi':
  deployed_name => 'keycloak-duo-spi-jar-with-dependencies.jar',
  source        => 'file:///path/to/source/keycloak-duo-spi-jar-with-dependencies.jar',
  test_url      => 'authentication/authenticator-providers',
  test_key      => 'id',
  test_value    => 'duo-mfa-authenticator',
  test_realm    => 'test',
  before        => Keycloak_flow_execution['duo-mfa-authenticator under form-browser-with-duo on test'],
```

#### Parameters

The following parameters are available in the `keycloak::spi_deployment` defined type:

* [`ensure`](#ensure)
* [`deployed_name`](#deployed_name)
* [`source`](#source)
* [`test_url`](#test_url)
* [`test_key`](#test_key)
* [`test_value`](#test_value)
* [`test_realm`](#test_realm)
* [`test_before`](#test_before)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the deployment

Default value: `'present'`

##### <a name="deployed_name"></a>`deployed_name`

Data type: `String[1]`

Name of the file to be deployed. Defaults to `$name`.

Default value: `$name`

##### <a name="source"></a>`source`

Data type: `Variant[Stdlib::Filesource, Stdlib::HTTPSUrl]`

Source of the deployment, supports 'file://', 'puppet://', 'https://' or 'http://'

##### <a name="test_url"></a>`test_url`

Data type: `Optional[String]`

URL to test for existance of resources created by this SPI

Default value: ``undef``

##### <a name="test_key"></a>`test_key`

Data type: `Optional[String]`

Key of resource when testing for resource created by this SPI

Default value: ``undef``

##### <a name="test_value"></a>`test_value`

Data type: `Optional[String]`

Value of the `test_key` when testing for resources created by this SPI

Default value: ``undef``

##### <a name="test_realm"></a>`test_realm`

Data type: `Optional[String]`

Realm to query when looking for resources created by this SPI

Default value: ``undef``

##### <a name="test_before"></a>`test_before`

Data type: `Optional[Array]`

Setup autorequires for validator dependent resources

Default value: ``undef``

### <a name="keycloaktruststorehost"></a>`keycloak::truststore::host`

Add host to Keycloak truststore

#### Examples

##### 

```puppet
keycloak::truststore::host { 'ldap1.example.com':
  certificate => '/etc/openldap/certs/0a00000.0',
}
```

#### Parameters

The following parameters are available in the `keycloak::truststore::host` defined type:

* [`certificate`](#certificate)
* [`ensure`](#ensure)

##### <a name="certificate"></a>`certificate`

Data type: `String`

Path to host certificate

##### <a name="ensure"></a>`ensure`

Data type: `Enum['latest', 'present', 'absent']`

Host ensure value passed to `java_ks` resource.

Default value: `'latest'`

## Resource types

### <a name="keycloak_api"></a>`keycloak_api`

Type that configures API connection parameters for other keycloak types that use the Keycloak API.

#### Examples

##### Define API access

```puppet
keycloak_api { 'keycloak'
  install_dir  => '/opt/keycloak',
  server       => 'http://localhost:8080/auth',
  realm        => 'master',
  user         => 'admin',
  password     => 'changeme',
}
```

#### Parameters

The following parameters are available in the `keycloak_api` type.

* [`install_dir`](#install_dir)
* [`name`](#name)
* [`password`](#password)
* [`realm`](#realm)
* [`server`](#server)
* [`use_wrapper`](#use_wrapper)
* [`user`](#user)

##### <a name="install_dir"></a>`install_dir`

Install location of Keycloak

Default value: `/opt/keycloak`

##### <a name="name"></a>`name`

namevar

Keycloak API config

##### <a name="password"></a>`password`

Password for authentication

Default value: `changeme`

##### <a name="realm"></a>`realm`

Realm for authentication

Default value: `master`

##### <a name="server"></a>`server`

Auth URL for Keycloak server

Default value: `http://localhost:8080/auth`

##### <a name="use_wrapper"></a>`use_wrapper`

Valid values: ``true``, ``false``

Boolean that determines if kcadm_wrapper.sh should be used

Default value: ``false``

##### <a name="user"></a>`user`

User for authentication

Default value: `admin`

### <a name="keycloak_client"></a>`keycloak_client`

Manage Keycloak clients

#### Examples

##### Add a OpenID Connect client

```puppet
keycloak_client { 'www.example.com':
  ensure                => 'present',
  realm                 => 'test',
  redirect_uris         => [
    "https://www.example.com/oidc",
    "https://www.example.com",
  ],
  default_client_scopes => ['profile','email'],
  secret                => 'supersecret',
}
```

#### Properties

The following properties are available in the `keycloak_client` type.

##### `access_token_lifespan`

access.token.lifespan

##### `authorization_services_enabled`

Valid values: ``true``, ``false``

authorizationServicesEnabled

Default value: `false`

##### `base_url`

baseUrl

##### `bearer_only`

Valid values: ``true``, ``false``

bearerOnly

Default value: `false`

##### `browser_flow`

authenticationFlowBindingOverrides.browser (Use flow alias, not ID)

Default value: `absent`

##### `client_authenticator_type`

clientAuthenticatorType

Default value: `client-secret`

##### `default_client_scopes`

defaultClientScopes

Default value: `[]`

##### `direct_access_grants_enabled`

Valid values: ``true``, ``false``

enabled

Default value: `true`

##### `direct_grant_flow`

authenticationFlowBindingOverrides.direct_grant (Use flow alias, not ID)

Default value: `absent`

##### `enabled`

Valid values: ``true``, ``false``

enabled

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `full_scope_allowed`

Valid values: ``true``, ``false``

fullScopeAllowed

Default value: `true`

##### `implicit_flow_enabled`

Valid values: ``true``, ``false``

implicitFlowEnabled

Default value: `false`

##### `login_theme`

login_theme

Default value: `absent`

##### `optional_client_scopes`

optionalClientScopes

Default value: `[]`

##### `protocol`

Valid values: `openid-connect`, `saml`

protocol

Default value: `openid-connect`

##### `public_client`

Valid values: ``true``, ``false``

enabled

Default value: `false`

##### `redirect_uris`

redirectUris

Default value: `[]`

##### `roles`

roles

Default value: `[]`

##### `root_url`

rootUrl

##### `secret`

secret

##### `service_accounts_enabled`

Valid values: ``true``, ``false``

serviceAccountsEnabled

Default value: `false`

##### `standard_flow_enabled`

Valid values: ``true``, ``false``

standardFlowEnabled

Default value: `true`

##### `web_origins`

webOrigins

Default value: `[]`

#### Parameters

The following parameters are available in the `keycloak_client` type.

* [`client_id`](#client_id)
* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)

##### <a name="client_id"></a>`client_id`

clientId. Defaults to `name`.

##### <a name="id"></a>`id`

Id. Defaults to `client_id`

##### <a name="name"></a>`name`

namevar

The client name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_client` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

realm

### <a name="keycloak_client_protocol_mapper"></a>`keycloak_client_protocol_mapper`

Manage Keycloak protocol mappers

#### Examples

##### Add email protocol mapper to test.example.com client in realm test

```puppet
keycloak_client_protocol_mapper { "email for test.example.com on test":
  claim_name     => 'email',
  user_attribute => 'email',
}
```

#### Properties

The following properties are available in the `keycloak_client_protocol_mapper` type.

##### `access_token_claim`

Valid values: ``true``, ``false``

access.token.claim. Default to `true` for `protocol` `openid-connect`.

##### `attribute_name`

attribute.name Default to `resource_name` for `type` `saml-user-property-mapper`.

##### `attribute_nameformat`

attribute.nameformat

##### `claim_name`

claim.name

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `friendly_name`

friendly.name. Default to `resource_name` for `type` `saml-user-property-mapper`.

##### `full_path`

Valid values: ``true``, ``false``

full.path. Default to `false` for `type` `oidc-group-membership-mapper`.

##### `id_token_claim`

Valid values: ``true``, ``false``

id.token.claim. Default to `true` for `protocol` `openid-connect`.

##### `included_client_audience`

included.client.audience Required for `type` of `oidc-audience-mapper`

##### `json_type_label`

json.type.label. Default to `String` for `type` `oidc-usermodel-property-mapper` and `oidc-group-membership-mapper`.

##### `protocol`

Valid values: `openid-connect`, `saml`

protocol

Default value: `openid-connect`

##### `script`

Script, only valid for `type` of `saml-javascript-mapper`'

Array values will be joined with newlines. Strings will be kept unchanged.

##### `single`

Valid values: ``true``, ``false``

single. Default to `false` for `type` `saml-role-list-mapper`.

##### `user_attribute`

user.attribute. Default to `resource_name` for `type` `oidc-usermodel-property-mapper` or `saml-user-property-mapper`

##### `userinfo_token_claim`

Valid values: ``true``, ``false``

userinfo.token.claim. Default to `true` for `protocol` `openid-connect` except `type` of `oidc-audience-mapper`.

#### Parameters

The following parameters are available in the `keycloak_client_protocol_mapper` type.

* [`client`](#client)
* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`resource_name`](#resource_name)
* [`type`](#type)

##### <a name="client"></a>`client`

client

##### <a name="id"></a>`id`

Id.

##### <a name="name"></a>`name`

namevar

The protocol mapper name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_client_protocol_mapper` resource. You will seldom need to specify this
--- Puppet will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

realm

##### <a name="resource_name"></a>`resource_name`

The protocol mapper name. Defaults to `name`.

##### <a name="type"></a>`type`

Valid values: `oidc-usermodel-client-role-mapper`, `oidc-usermodel-property-mapper`, `oidc-full-name-mapper`, `oidc-group-membership-mapper`, `oidc-audience-mapper`, `saml-user-property-mapper`, `saml-role-list-mapper`

protocolMapper.

Default is `oidc-usermodel-property-mapper` for `protocol` `openid-connect` and
`saml-user-property-mapper` for `protocol` `saml`.

### <a name="keycloak_client_scope"></a>`keycloak_client_scope`

Manage Keycloak client scopes

#### Examples

##### Define a OpenID Connect client scope in the test realm

```puppet
keycloak_client_scope { 'email on test':
  protocol => 'openid-connect',
}
```

#### Properties

The following properties are available in the `keycloak_client_scope` type.

##### `consent_screen_text`

consent.screen.text

##### `display_on_consent_screen`

Valid values: ``true``, ``false``

display.on.consent.screen

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `protocol`

Valid values: `openid-connect`, `saml`

protocol

Default value: `openid-connect`

#### Parameters

The following parameters are available in the `keycloak_client_scope` type.

* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`resource_name`](#resource_name)

##### <a name="id"></a>`id`

Id. Defaults to `resource_name`.

##### <a name="name"></a>`name`

namevar

The client scope name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_client_scope` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

realm

##### <a name="resource_name"></a>`resource_name`

The client scope name. Defaults to `name`.

### <a name="keycloak_conn_validator"></a>`keycloak_conn_validator`

Verify that a connection can be successfully established between a node
and the keycloak server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the keycloak
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Properties

The following properties are available in the `keycloak_conn_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `keycloak_conn_validator` type.

* [`keycloak_port`](#keycloak_port)
* [`keycloak_server`](#keycloak_server)
* [`name`](#name)
* [`provider`](#provider)
* [`test_url`](#test_url)
* [`timeout`](#timeout)
* [`use_ssl`](#use_ssl)

##### <a name="keycloak_port"></a>`keycloak_port`

The port that the keycloak server should be listening on.

Default value: `8080`

##### <a name="keycloak_server"></a>`keycloak_server`

The DNS name or IP address of the server where keycloak should be running.

Default value: `localhost`

##### <a name="name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_conn_validator` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="test_url"></a>`test_url`

URL to use for testing if the Keycloak database is up

Default value: `/auth/admin/serverinfo`

##### <a name="timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that keycloak is not running;
defaults to 15 seconds.

Default value: `30`

##### <a name="use_ssl"></a>`use_ssl`

Whether the connection will be attemped using https

Default value: ``false``

### <a name="keycloak_flow"></a>`keycloak_flow`

Manage a Keycloak flow
**Autorequires**
* `keycloak_realm` defined for `realm` parameter
* `keycloak_flow` of `flow_alias` if `top_level=false`
* `keycloak_flow` of `flow_alias` if other `index` is lower and if `top_level=false`
* `keycloak_flow_execution` if `flow_alias` is the same and other `index` is lower and if `top_level=false`

#### Examples

##### Add custom flow

```puppet
keycloak_flow { 'browser-with-duo':
  ensure => 'present',
  realm  => 'test',
}
```

##### Add a flow execution to existing browser-with-duo flow

```puppet
keycloak_flow { 'form-browser-with-duo under browser-with-duo on test':
  ensure      => 'present',
  index       => 2,
  requirement => 'ALTERNATIVE',
  top_level   => false,
}
```

#### Properties

The following properties are available in the `keycloak_flow` type.

##### `description`

description

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `index`

execution index, only applied to top_level=false, required for top_level=false

##### `requirement`

Valid values: `DISABLED`, `ALTERNATIVE`, `REQUIRED`, `CONDITIONAL`, `disabled`, `alternative`, `required`, `conditional`

requirement, only applied to top_level=false and defaults to DISABLED

#### Parameters

The following parameters are available in the `keycloak_flow` type.

* [`alias`](#alias)
* [`flow_alias`](#flow_alias)
* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`provider_id`](#provider_id)
* [`realm`](#realm)
* [`top_level`](#top_level)
* [`type`](#type)

##### <a name="alias"></a>`alias`

Alias. Default to `name`.

##### <a name="flow_alias"></a>`flow_alias`

flowAlias, required for top_level=false

##### <a name="id"></a>`id`

Id. Default to `$alias-$realm` when top_level is true. Only applies to top_level=true

##### <a name="name"></a>`name`

namevar

The flow name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_flow` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="provider_id"></a>`provider_id`

Valid values: `basic-flow`, `form-flow`

providerId

Default value: `basic-flow`

##### <a name="realm"></a>`realm`

realm

##### <a name="top_level"></a>`top_level`

Valid values: ``true``, ``false``

topLevel

Default value: ``true``

##### <a name="type"></a>`type`

sub-flow execution provider, default to `registration-page-form` for top_level=false and does not apply to
top_level=true

### <a name="keycloak_flow_execution"></a>`keycloak_flow_execution`

Manage a Keycloak flow
**Autorequires**
* `keycloak_realm` defined for `realm` parameter
* `keycloak_flow` of value defined for `flow_alias`
* `keycloak_flow` if they share same `flow_alias` value and the other resource `index` is lower
* `keycloak_flow_execution` if `flow_alias` is the same and other `index` is lower

#### Examples

##### Add an execution to a flow

```puppet
keycloak_flow_execution { 'auth-cookie under browser-with-duo on test':
  ensure       => 'present',
  configurable => false,
  display_name => 'Cookie',
  index        => 0,
  requirement  => 'ALTERNATIVE',
}
```

##### Add an execution to a execution flow that is one level deeper than top level

```puppet
keycloak_flow_execution { 'auth-username-password-form under form-browser-with-duo on test':
  ensure       => 'present',
  configurable => false,
  display_name => 'Username Password Form',
  index        => 0,
  requirement  => 'REQUIRED',
}
```

##### Add an execution with a configuration

```puppet
keycloak_flow_execution { 'duo-mfa-authenticator under form-browser-with-duo on test':
  ensure       => 'present',
  configurable => true,
  display_name => 'Duo MFA',
  alias        => 'Duo',
  config       => {
    "duomfa.akey"    => "foo-akey",
    "duomfa.apihost" => "api-foo.duosecurity.com",
    "duomfa.skey"    => "secret",
    "duomfa.ikey"    => "foo-ikey",
    "duomfa.groups"  => "duo"
  },
  requirement  => 'REQUIRED',
  index        => 1,
}
```

#### Properties

The following properties are available in the `keycloak_flow_execution` type.

##### `config`

execution config

##### `configurable`

Valid values: ``true``, ``false``

configurable

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `index`

execution index

##### `requirement`

Valid values: `DISABLED`, `ALTERNATIVE`, `REQUIRED`, `CONDITIONAL`, `disabled`, `alternative`, `required`, `conditional`

requirement

Default value: `DISABLED`

#### Parameters

The following parameters are available in the `keycloak_flow_execution` type.

* [`alias`](#alias)
* [`config_id`](#config_id)
* [`display_name`](#display_name)
* [`flow_alias`](#flow_alias)
* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`provider_id`](#provider_id)
* [`realm`](#realm)

##### <a name="alias"></a>`alias`

alias

##### <a name="config_id"></a>`config_id`

read-only config ID

##### <a name="display_name"></a>`display_name`

displayName

##### <a name="flow_alias"></a>`flow_alias`

flowAlias

##### <a name="id"></a>`id`

read-only Id

##### <a name="name"></a>`name`

namevar

The flow execution name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_flow_execution` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="provider_id"></a>`provider_id`

provider

##### <a name="realm"></a>`realm`

realm

### <a name="keycloak_identity_provider"></a>`keycloak_identity_provider`

Manage Keycloak identity providers

#### Examples

##### Add CILogon identity provider to test realm

```puppet
keycloak_identity_provider { 'cilogon on test':
  ensure                         => 'present',
  display_name                   => 'CILogon',
  provider_id                    => 'oidc',
  first_broker_login_flow_alias  => 'browser',
  client_id                      => 'cilogon:/client_id/foobar',
  client_secret                  => 'supersecret',
  user_info_url                  => 'https://cilogon.org/oauth2/userinfo',
  token_url                      => 'https://cilogon.org/oauth2/token',
  authorization_url              => 'https://cilogon.org/authorize',
}
```

#### Properties

The following properties are available in the `keycloak_identity_provider` type.

##### `add_read_token_role_on_create`

Valid values: ``true``, ``false``

addReadTokenRoleOnCreate

Default value: `false`

##### `allowed_clock_skew`

allowedClockSkew

##### `authenticate_by_default`

Valid values: ``true``, ``false``

authenticateByDefault

Default value: `false`

##### `authorization_url`

authorizationUrl

##### `backchannel_supported`

Valid values: ``true``, ``false``

backchannelSupported

Default value: `false`

##### `client_auth_method`

Valid values: `client_secret_post`, `client_secret_basic`, `client_secret_jwt`, `private_key_jwt`

clientAuthMethod

Default value: `client_secret_post`

##### `client_id`

clientId

##### `client_secret`

clientSecret

##### `default_scope`

default_scope

##### `disable_user_info`

Valid values: ``true``, ``false``

disableUserInfo

Default value: `false`

##### `display_name`

displayName

##### `enabled`

Valid values: ``true``, ``false``

enabled

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `first_broker_login_flow_alias`

firstBrokerLoginFlowAlias

Default value: `first broker login`

##### `forward_parameters`

forwardParameters

##### `gui_order`

guiOrder

##### `hide_on_login_page`

Valid values: ``true``, ``false``

hideOnLoginPage

Default value: `false`

##### `issuer`

issuer

##### `jwks_url`

jwksUrl

##### `link_only`

Valid values: ``true``, ``false``

linkOnly

Default value: `false`

##### `login_hint`

Valid values: ``true``, ``false``

loginHint

Default value: `false`

##### `logout_url`

logoutUrl

##### `post_broker_login_flow_alias`

postBrokerLoginFlowAlias

##### `prompt`

Valid values: `none`, `consent`, `login`, `select_account`

prompt

##### `store_token`

Valid values: ``true``, ``false``

storeToken

Default value: `false`

##### `sync_mode`

Valid values: `IMPORT`, `LEGACY`, `FORCE`

syncMode

Default value: `IMPORT`

##### `token_url`

tokenUrl

##### `trust_email`

Valid values: ``true``, ``false``

trustEmail

Default value: `false`

##### `ui_locales`

Valid values: ``true``, ``false``

uiLocales

Default value: `false`

##### `update_profile_first_login_mode`

Valid values: `on`, `off`

updateProfileFirstLoginMode

Default value: `on`

##### `use_jwks_url`

Valid values: ``true``, ``false``

useJwksUrl

Default value: `true`

##### `user_info_url`

userInfoUrl

##### `validate_signature`

Valid values: ``true``, ``false``

validateSignature

Default value: `false`

#### Parameters

The following parameters are available in the `keycloak_identity_provider` type.

* [`alias`](#alias)
* [`internal_id`](#internal_id)
* [`name`](#name)
* [`provider`](#provider)
* [`provider_id`](#provider_id)
* [`realm`](#realm)

##### <a name="alias"></a>`alias`

The identity provider name. Defaults to `name`.

##### <a name="internal_id"></a>`internal_id`

internalId. Defaults to "`alias`-`realm`"

##### <a name="name"></a>`name`

namevar

The identity provider name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_identity_provider` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="provider_id"></a>`provider_id`

Valid values: `oidc`, `keycloak-oidc`

providerId

Default value: `oidc`

##### <a name="realm"></a>`realm`

realm

### <a name="keycloak_ldap_mapper"></a>`keycloak_ldap_mapper`

Manage Keycloak LDAP attribute mappers

#### Examples

##### Add full name attribute mapping

```puppet
keycloak_ldap_mapper { 'full name for LDAP-test on test:
  ensure         => 'present',
  type           => 'full-name-ldap-mapper',
  ldap_attribute => 'gecos',
}
```

#### Properties

The following properties are available in the `keycloak_ldap_mapper` type.

##### `always_read_value_from_ldap`

Valid values: ``true``, ``false``

always.read.value.from.ldap. Defaults to `true` if `type` is `user-attribute-ldap-mapper`.

##### `client_id`

client.id, only for `type` of `role-ldap-mapper`

##### `drop_non_existing_groups_during_sync`

Valid values: ``true``, ``false``

drop.non.existing.groups.during.sync, only for `type` of `group-ldap-mapper`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `group_name_ldap_attribute`

group.name.ldap.attribute, only for `type` of `group-ldap-mapper`

##### `group_object_classes`

group.object.classes, only for `type` of `group-ldap-mapper`

##### `groups_dn`

groups.dn, only for `type` of `group-ldap-mapper`

##### `groups_ldap_filter`

groups.ldap.filter, only for `type` of `group-ldap-mapper`

##### `ignore_missing_groups`

Valid values: ``true``, ``false``

ignore.missing.groups, only for `type` of `group-ldap-mapper`

##### `is_mandatory_in_ldap`

is.mandatory.in.ldap. Defaults to `false` unless `type` is `full-name-ldap-mapper`.

##### `ldap_attribute`

ldap.attribute

##### `mapped_group_attributes`

mapped.group.attributes, only for `type` of `group-ldap-mapper`

##### `memberof_ldap_attribute`

memberof.ldap.attribute, only for `type` of `group-ldap-mapper` and `role-ldap-mapper`

##### `membership_attribute_type`

Valid values: `DN`, `UID`

membership.attribute.type, only for `type` of `group-ldap-mapper` and `role-ldap-mapper`

##### `membership_ldap_attribute`

membership.ldap.attribute, only for `type` of `group-ldap-mapper` and `role-ldap-mapper`

##### `membership_user_ldap_attribute`

membership.user.ldap.attribute, only for `type` of `group-ldap-mapper` and `role-ldap-mapper`

##### `mode`

Valid values: `READ_ONLY`, `LDAP_ONLY`

mode, only for `type` of `group-ldap-mapper` and `role-ldap-mapper`

##### `preserve_group_inheritance`

Valid values: ``true``, ``false``

preserve.group.inheritance, only for `type` of `group-ldap-mapper`

##### `read_only`

Valid values: ``true``, ``false``

read.only

##### `role_name_ldap_attribute`

role.name.ldap.attribute, only for `type` of `role-ldap-mapper`

##### `role_object_classes`

role.object.classes, only for `type` of `role-ldap-mapper`

##### `roles_dn`

roles.dn, only for `type` of `role-ldap-mapper`

##### `roles_ldap_filter`

roles.ldap.filter, only for `type` of `role-ldap-mapper`

##### `use_realm_roles_mapping`

Valid values: ``true``, ``false``

use.realm.roles.mapping, only for `type` of `role-ldap-mapper`

##### `user_model_attribute`

user.model.attribute

##### `user_roles_retrieve_strategy`

Valid values: `LOAD_GROUPS_BY_MEMBER_ATTRIBUTE`, `GET_GROUPS_FROM_USER_MEMBEROF_ATTRIBUTE`, `LOAD_GROUPS_BY_MEMBER_ATTRIBUTE_RECURSIVELY`, `LOAD_ROLES_BY_MEMBER_ATTRIBUTE`, `GET_ROLES_FROM_USER_MEMBEROF_ATTRIBUTE`, `LOAD_ROLES_BY_MEMBER_ATTRIBUTE_RECURSIVELY`

user.roles.retrieve.strategy, only for `type` of `group-ldap-mapper` and `role-ldap-mapper`

##### `write_only`

Valid values: ``true``, ``false``

write.only.  Defaults to `false` if `type` is `full-name-ldap-mapper`.

#### Parameters

The following parameters are available in the `keycloak_ldap_mapper` type.

* [`id`](#id)
* [`ldap`](#ldap)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`resource_name`](#resource_name)
* [`type`](#type)

##### <a name="id"></a>`id`

Id.

##### <a name="ldap"></a>`ldap`

parentId

##### <a name="name"></a>`name`

namevar

The LDAP mapper name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_ldap_mapper` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

realm

##### <a name="resource_name"></a>`resource_name`

The LDAP mapper name. Defaults to `name`

##### <a name="type"></a>`type`

Valid values: `user-attribute-ldap-mapper`, `full-name-ldap-mapper`, `group-ldap-mapper`, `role-ldap-mapper`

providerId

Default value: `user-attribute-ldap-mapper`

### <a name="keycloak_ldap_user_provider"></a>`keycloak_ldap_user_provider`

Manage Keycloak LDAP user providers

#### Examples

##### Add LDAP user provider to test realm

```puppet
keycloak_ldap_user_provider { 'LDAP on test':
  ensure             => 'present',
  users_dn           => 'ou=People,dc=example,dc=com',
  connection_url     => 'ldaps://ldap1.example.com:636 ldaps://ldap2.example.com:636',
  import_enabled     => false,
  use_truststore_spi => 'never',
}
```

#### Properties

The following properties are available in the `keycloak_ldap_user_provider` type.

##### `auth_type`

Valid values: `none`, `simple`

authType

Default value: `none`

##### `batch_size_for_sync`

batchSizeForSync

Default value: `1000`

##### `bind_credential`

bindCredential

##### `bind_dn`

bindDn

##### `changed_sync_period`

changedSyncPeriod

Default value: `-1`

##### `connection_url`

connectionUrl

##### `custom_user_search_filter`

Valid values: `%r{.*}`, `absent`

customUserSearchFilter

Default value: `absent`

##### `edit_mode`

Valid values: `READ_ONLY`, `WRITABLE`, `UNSYNCED`

editMode

Default value: `READ_ONLY`

##### `enabled`

Valid values: ``true``, ``false``

enabled

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `full_sync_period`

fullSyncPeriod

Default value: `-1`

##### `import_enabled`

Valid values: ``true``, ``false``

importEnabled

Default value: `true`

##### `priority`

priority

Default value: `0`

##### `rdn_ldap_attribute`

rdnLdapAttribute

Default value: `uid`

##### `search_scope`

Valid values: `one`, `one_level`, `subtree`, `1`, `2`, `1`, `2`

searchScope

##### `trust_email`

Valid values: ``true``, ``false``

trustEmail

Default value: `false`

##### `use_kerberos_for_password_authentication`

Valid values: ``true``, ``false``

useKerberosForPasswordAuthentication

##### `use_truststore_spi`

Valid values: `always`, `ldapsOnly`, `never`

useTruststoreSpi

Default value: `ldapsOnly`

##### `user_object_classes`

userObjectClasses

Default value: `['inetOrgPerson', 'organizationalPerson']`

##### `username_ldap_attribute`

usernameLdapAttribute

Default value: `uid`

##### `users_dn`

usersDn

##### `uuid_ldap_attribute`

uuidLdapAttribute

Default value: `entryUUID`

##### `vendor`

Valid values: `ad`, `rhds`, `tivoli`, `eDirectory`, `other`

vendor

Default value: `other`

#### Parameters

The following parameters are available in the `keycloak_ldap_user_provider` type.

* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`resource_name`](#resource_name)

##### <a name="id"></a>`id`

Id. Defaults to "`resource_name`-`realm`"

##### <a name="name"></a>`name`

namevar

The LDAP user provider name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_ldap_user_provider` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

parentId

##### <a name="resource_name"></a>`resource_name`

The LDAP user provider name. Defaults to `name`.

### <a name="keycloak_protocol_mapper"></a>`keycloak_protocol_mapper`

Manage Keycloak client scope protocol mappers

#### Examples

##### Add email protocol mapper to oidc-client client scope in realm test

```puppet
keycloak_protocol_mapper { "email for oidc-clients on test":
  claim_name     => 'email',
  user_attribute => 'email',
}
```

#### Properties

The following properties are available in the `keycloak_protocol_mapper` type.

##### `access_token_claim`

Valid values: ``true``, ``false``

access.token.claim. Default to `true` for `protocol` `openid-connect`.

##### `attribute_name`

attribute.name Default to `resource_name` for `type` `saml-user-property-mapper`.

##### `attribute_nameformat`

attribute.nameformat

##### `claim_name`

claim.name

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `friendly_name`

friendly.name. Default to `resource_name` for `type` `saml-user-property-mapper`.

##### `full_path`

Valid values: ``true``, ``false``

full.path. Default to `false` for `type` `oidc-group-membership-mapper`.

##### `id_token_claim`

Valid values: ``true``, ``false``

id.token.claim. Default to `true` for `protocol` `openid-connect`.

##### `included_client_audience`

included.client.audience Required for `type` of `oidc-audience-mapper`

##### `json_type_label`

json.type.label. Default to `String` for `type` `oidc-usermodel-property-mapper` and `oidc-group-membership-mapper`.

##### `protocol`

Valid values: `openid-connect`, `saml`

protocol

Default value: `openid-connect`

##### `script`

Script, only valid for `type` of `saml-javascript-mapper`'

Array values will be joined with newlines. Strings will be kept unchanged.

##### `single`

Valid values: ``true``, ``false``

single. Default to `false` for `type` `saml-role-list-mapper` or `saml-javascript-mapper`.

##### `user_attribute`

user.attribute. Default to `resource_name` for `type` `oidc-usermodel-property-mapper` or `saml-user-property-mapper`

##### `userinfo_token_claim`

Valid values: ``true``, ``false``

userinfo.token.claim. Default to `true` for `protocol` `openid-connect` except `type` of `oidc-audience-mapper`.

#### Parameters

The following parameters are available in the `keycloak_protocol_mapper` type.

* [`client_scope`](#client_scope)
* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`resource_name`](#resource_name)
* [`type`](#type)

##### <a name="client_scope"></a>`client_scope`

client scope

##### <a name="id"></a>`id`

Id.

##### <a name="name"></a>`name`

namevar

The protocol mapper name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_protocol_mapper` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

realm

##### <a name="resource_name"></a>`resource_name`

The protocol mapper name. Defaults to `name`.

##### <a name="type"></a>`type`

Valid values: `oidc-usermodel-property-mapper`, `oidc-usermodel-attribute-mapper`, `oidc-full-name-mapper`, `oidc-group-membership-mapper`, `oidc-audience-mapper`, `saml-group-membership-mapper`, `saml-user-property-mapper`, `saml-user-attribute-mapper`, `saml-role-list-mapper`

protocolMapper.

Default is `oidc-usermodel-property-mapper` for `protocol` `openid-connect` and
`saml-user-property-mapper` for `protocol` `saml`.

### <a name="keycloak_realm"></a>`keycloak_realm`

Manage Keycloak realms

#### Examples

##### Add a realm with a custom theme

```puppet
keycloak_realm { 'test':
  ensure                   => 'present',
  remember_me              => true,
  login_with_email_allowed => false,
  login_theme              => 'my_theme',
}
```

#### Properties

The following properties are available in the `keycloak_realm` type.

##### `access_code_lifespan`

accessCodeLifespan

##### `access_code_lifespan_login`

accessCodeLifespanLogin

##### `access_code_lifespan_user_action`

accessCodeLifespanUserAction

##### `access_token_lifespan`

accessTokenLifespan

##### `access_token_lifespan_for_implicit_flow`

accessTokenLifespanForImplicitFlow

##### `account_theme`

accountTheme

Default value: `keycloak`

##### `action_token_generated_by_admin_lifespan`

actionTokenGeneratedByAdminLifespan

##### `action_token_generated_by_user_lifespan`

actionTokenGeneratedByUserLifespan

##### `admin_events_details_enabled`

Valid values: ``true``, ``false``

adminEventsDetailsEnabled

Default value: `false`

##### `admin_events_enabled`

Valid values: ``true``, ``false``

adminEventsEnabled

Default value: `false`

##### `admin_theme`

adminTheme

Default value: `keycloak`

##### `browser_flow`

browserFlow

Default value: `browser`

##### `brute_force_protected`

Valid values: ``true``, ``false``

bruteForceProtected

##### `client_authentication_flow`

clientAuthenticationFlow

Default value: `clients`

##### `content_security_policy`

contentSecurityPolicy

Default value: `frame-src 'self'; frame-ancestors 'self'; object-src 'none';`

##### `custom_properties`

custom properties to pass as realm configurations

##### `default_client_scopes`

Default Client Scopes

##### `direct_grant_flow`

directGrantFlow

Default value: `direct grant`

##### `display_name`

displayName

##### `display_name_html`

displayNameHtml

##### `docker_authentication_flow`

dockerAuthenticationFlow

Default value: `docker auth`

##### `edit_username_allowed`

Valid values: ``true``, ``false``

editUsernameAllowed

Default value: `false`

##### `email_theme`

emailTheme

Default value: `keycloak`

##### `enabled`

Valid values: ``true``, ``false``

enabled

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `events_enabled`

Valid values: ``true``, ``false``

eventsEnabled

Default value: `false`

##### `events_expiration`

eventsExpiration

##### `events_listeners`

eventsListeners

Default value: `['jboss-logging']`

##### `internationalization_enabled`

Valid values: ``true``, ``false``

internationalizationEnabled

Default value: `false`

##### `login_theme`

loginTheme

Default value: `keycloak`

##### `login_with_email_allowed`

Valid values: ``true``, ``false``

loginWithEmailAllowed

Default value: `true`

##### `offline_session_idle_timeout`

offlineSessionIdleTimeout

##### `offline_session_max_lifespan`

offlineSessionMaxLifespan

##### `offline_session_max_lifespan_enabled`

Valid values: ``true``, ``false``

offlineSessionMaxLifespanEnabled

Default value: `false`

##### `optional_client_scopes`

Optional Client Scopes

##### `registration_allowed`

Valid values: ``true``, ``false``

registrationAllowed

Default value: `false`

##### `registration_flow`

registrationFlow

Default value: `registration`

##### `remember_me`

Valid values: ``true``, ``false``

rememberMe

Default value: `false`

##### `reset_credentials_flow`

resetCredentialsFlow

Default value: `reset credentials`

##### `reset_password_allowed`

Valid values: ``true``, ``false``

resetPasswordAllowed

Default value: `false`

##### `roles`

roles

Default value: `['offline_access', 'uma_authorization']`

##### `smtp_server_auth`

Valid values: ``true``, ``false``

smtpServer auth

##### `smtp_server_envelope_from`

smtpServer envelope_from

##### `smtp_server_from`

smtpServer from

##### `smtp_server_from_display_name`

smtpServer fromDisplayName

##### `smtp_server_host`

smtpServer host

##### `smtp_server_password`

smtpServer password

##### `smtp_server_port`

smtpServer port

##### `smtp_server_reply_to`

smtpServer replyto

##### `smtp_server_reply_to_display_name`

smtpServer replyToDisplayName

##### `smtp_server_ssl`

Valid values: ``true``, ``false``

smtpServer ssl

##### `smtp_server_starttls`

Valid values: ``true``, ``false``

smtpServer starttls

##### `smtp_server_user`

smtpServer user

##### `ssl_required`

Valid values: `none`, `all`, `external`

sslRequired

Default value: `external`

##### `sso_session_idle_timeout`

ssoSessionIdleTimeout

##### `sso_session_idle_timeout_remember_me`

ssoSessionIdleTimeoutRememberMe

##### `sso_session_max_lifespan`

ssoSessionMaxLifespan

##### `sso_session_max_lifespan_remember_me`

ssoSessionMaxLifespanRememberMe

##### `supported_locales`

Supported Locales

##### `user_managed_access_allowed`

Valid values: ``true``, ``false``

userManagedAccessAllowed

Default value: `false`

##### `verify_email`

Valid values: ``true``, ``false``

verifyEmail

Default value: `false`

#### Parameters

The following parameters are available in the `keycloak_realm` type.

* [`id`](#id)
* [`manage_roles`](#manage_roles)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="id"></a>`id`

Id. Default to `name`.

##### <a name="manage_roles"></a>`manage_roles`

Valid values: ``true``, ``false``

Manage realm roles

Default value: ``true``

##### <a name="name"></a>`name`

namevar

The realm name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_realm` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="keycloak_required_action"></a>`keycloak_required_action`

Manage Keycloak required actions

#### Examples

##### Enable Webauthn Register and make it default

```puppet
keycloak_required_action { 'webauthn-register on master':
  ensure => present,
  provider_id => 'webauthn-register',
  display_name => 'Webauthn Register',
  default => true,
  enabled => true,
  priority => 1,
  config => {
    'something' => 'true', # keep in mind that keycloak only supports strings for both keys and values
    'smth else' => '1',
  },
  alias => 'webauthn',
}

@example Minimal example to enable email verification without making it default
keycloak_required_action { 'VERIFY_EMAIL on master':
  ensure => present,
  provider_id => 'webauthn-register',
}
```

#### Properties

The following properties are available in the `keycloak_required_action` type.

##### `alias`

Alias. Default to `provider_id`.

##### `config`

Required action config

##### `default`

Valid values: ``true``, ``false``

If the required action is a default one. Default to false

Default value: `false`

##### `display_name`

Displayed name. Default to `provider_id`

##### `enabled`

Valid values: ``true``, ``false``

If the required action is enabled. Default to true.

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `priority`

Required action priority

#### Parameters

The following parameters are available in the `keycloak_required_action` type.

* [`name`](#name)
* [`provider`](#provider)
* [`provider_id`](#provider_id)
* [`realm`](#realm)

##### <a name="name"></a>`name`

namevar

The required action name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_required_action` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="provider_id"></a>`provider_id`

providerId of the required action

##### <a name="realm"></a>`realm`

realm

### <a name="keycloak_resource_validator"></a>`keycloak_resource_validator`

Verify that a specific Keycloak resource is available

#### Properties

The following properties are available in the `keycloak_resource_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `keycloak_resource_validator` type.

* [`dependent_resources`](#dependent_resources)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`test_key`](#test_key)
* [`test_url`](#test_url)
* [`test_value`](#test_value)
* [`timeout`](#timeout)

##### <a name="dependent_resources"></a>`dependent_resources`

Resources that should autorequire this validator, eg: Keycloak_flow_execution[foobar]

##### <a name="name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_resource_validator` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

Realm to query

##### <a name="test_key"></a>`test_key`

Key to lookup

##### <a name="test_url"></a>`test_url`

URL to use for testing if the Keycloak database is up

##### <a name="test_value"></a>`test_value`

Value to lookup

##### <a name="timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that keycloak is not running;
defaults to 15 seconds.

Default value: `30`

### <a name="keycloak_sssd_user_provider"></a>`keycloak_sssd_user_provider`

Manage Keycloak SSSD user providers

#### Examples

##### Add SSSD user provider to test realm

```puppet
keycloak_sssd_user_provider { 'SSSD on test':
  ensure => 'present',
}
```

#### Properties

The following properties are available in the `keycloak_sssd_user_provider` type.

##### `cache_policy`

Valid values: `DEFAULT`, `EVICT_DAILY`, `EVICT_WEEKLY`, `MAX_LIFESPAN`, `NO_CACHE`

cachePolicy

Default value: `DEFAULT`

##### `enabled`

Valid values: ``true``, ``false``

enabled

Default value: `true`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `eviction_day`

evictionDay

##### `eviction_hour`

evictionHour

##### `eviction_minute`

evictionMinute

##### `max_lifespan`

maxLifespan

##### `priority`

priority

Default value: `0`

#### Parameters

The following parameters are available in the `keycloak_sssd_user_provider` type.

* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)
* [`realm`](#realm)
* [`resource_name`](#resource_name)

##### <a name="id"></a>`id`

Id. Defaults to "`resource_name`-`realm`"

##### <a name="name"></a>`name`

namevar

The SSSD user provider name

##### <a name="provider"></a>`provider`

The specific backend to use for this `keycloak_sssd_user_provider` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="realm"></a>`realm`

parentId

##### <a name="resource_name"></a>`resource_name`

The SSSD user provider name. Defaults to `name`.

